@@ -1,10 +1,11 @@
 import * as React from 'react';
-import { Button, Dialog, DialogActions, DialogContent, DialogTitle, Grid } from '@material-ui/core';
+import { Button, Dialog, DialogActions, DialogContent, DialogTitle } from '@material-ui/core';
 
 interface ICellMetadataEditorDialog {
     open: boolean;
     title: string;
-    dialogContent: string;
+    content: string;
+    code: string;
     toggleDialog: Function;
 }
 
@@ -26,22 +27,19 @@ export const CellMetadataEditorDialog: React.FunctionComponent<ICellMetadataEdit
             <DialogTitle id="scroll-dialog-title">
                 <p className={'dialog-title'} >{props.title}</p>
             </DialogTitle>
-            <DialogContent dividers={true} style={{ paddingTop: 0 }}>
-                <Grid container direction="column" justify="center" alignItems="center">
-                    <Grid
-                        container
-                        direction="row"
-                        justify="space-between"
-                        alignItems="center"
-                        style={{ marginTop: '15px' }}
-                    >
-                        <p>{props.dialogContent}</p>
-                    </Grid>
-                </Grid>
+            <DialogContent dividers={true}>
+                <p>
+                    {props.content}
+                </p>
+                <div className={ 'dialog-code-snippet' + ((props.code)? '' : ' hidden') }>
+                    <code style={{ whiteSpace: "pre"}}>
+                        {props.code}
+                    </code>
+                </div>
             </DialogContent>
             <DialogActions>
                 <Button onClick={handleClose} color="primary">Ok</Button>
             </DialogActions>
-    </Dialog>
-  );
+        </Dialog>
+    );
 };
